@@ -21,7 +21,7 @@ this_file = Path((inspect.stack()[0])[1])
 this_dir  = this_file.directory
 
 ###############################################################################
-def test_vsearch():
+def test_vsearch(verbose=True):
     # The input fasta #
     fasta = this_dir.find('*.fasta')
     # The output directory #
@@ -35,9 +35,8 @@ def test_vsearch():
     # Run it #
     c()
     # Check that the results are good #
-    assert c.queries[0].taxonomy[0] == "Micrococcaceae"
-    # Here with VSEARCH we end up one level above as compared to BLAST #
-    assert c.queries[1].taxonomy[0] == "Propionibacteriales"
+    assert c.queries_by_id['Kocuria'].taxonomy[0] == "Kocuria"
+    assert c.queries_by_id['Marmoricola'].taxonomy[0] == "Marmoricola"
     # Return #
     return c
 
